@@ -2,6 +2,7 @@
 ** Job Arranger for ZABBIX
 ** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
 ** Copyright (C) 2013 Daiwa Institute of Research Business Innovation Ltd. All Rights Reserved.
+** Copyright (C) 2021 Daiwa Institute of Research Ltd. All Rights Reserved.
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,19 +19,14 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-/*
-** $Date:: 2020-06-10 16:58:10 +0900 #$
-** $Revision: 7523 $
-** $Author: sypark@FITECHLABS.CO.JP $
-**/
 
 #ifndef JOBARG_JACOMMON_H
 #define JOBARG_JACOMMON_H
 
 /* version or revsion */
-#define JOBARG_VERSION          	"5.0.0"
-#define JOBARG_REVISION         	"7532"
-#define JOBARG_REVDATE			"2020-06-10"
+#define JOBARG_VERSION          	"5.1.0"
+#define JOBARG_REVISION         	"1849"
+#define JOBARG_REVDATE			"2021-11-26"
 
 /* treat unknown parameters as error */
 #define JA_CFG_STRICT			0
@@ -59,7 +55,10 @@
 #define JA_KIND_LEN			16
 #define JA_SERVERID_LEN			18
 #define JA_COMMAND_ID_LEN		32 + 1
-
+#define JA_ENV_LEN				64000 + 64000 + 4096 + 1
+//added by ThihaOo@dat
+#define JA_MAX_READ_LEN			101
+#define JA_FILE_PATH_LEN		260
 /* extjob command */
 #define JA_CMD_SLEEP			"jacmdsleep"
 #define JA_CMD_TIME			"jacmdtime"
@@ -263,6 +262,8 @@
 #define JA_PROTO_TAG_KIND		"kind"
 #define JA_PROTO_TAG_VERSION		"version"
 #define JA_PROTO_TAG_SERVERID		"serverid"
+#define JA_PROTO_TAG_SERVERIP		"serverip"
+#define JA_PROTO_TAG_SEND_RETRY		"sendretry"
 #define JA_PROTO_TAG_DATA		"data"
 #define JA_PROTO_TELE_VERSION		JA_PROTO_VALUE_VERSION_1
 #define JA_PROTO_VALUE_VERSION_1	1
@@ -361,6 +362,11 @@
 #define JA_AGENT_STATUS_END		2
 #define JA_AGENT_STATUS_CLOSE		3
 
+//Added by ThihaOo@dat
+/* job file read_all_file*/
+#define JA_FILE_NAME_LEN		53+1
+#define JA_PERMISSION      0755
+
 /* job arranger agent interface data */
 typedef struct {
     char		kind[JA_KIND_LEN];
@@ -372,7 +378,7 @@ typedef struct {
     char		type[JA_MAX_STRING_LEN];
     char		argument[JA_MAX_DATA_LEN];
     char		script[JA_MAX_DATA_LEN];
-    char		env[JA_MAX_DATA_LEN];
+    char		env[JA_ENV_LEN];
     int			result;
     int			status;
     JA_PID		pid;
@@ -391,4 +397,9 @@ typedef struct {
     char       serverip[JA_SERVERID_LEN];
 } ja_job_object;
 
+/* Job file read object.*/
+typedef struct {
+    char        filename[JA_FILE_NAME_LEN];
+} ja_file_object;
+
 #endif  /* JOBARG_JACOMMON_H */
