@@ -2,6 +2,7 @@
 ** Job Arranger for ZABBIX
 ** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
 ** Copyright (C) 2013 Daiwa Institute of Research Business Innovation Ltd. All Rights Reserved.
+** Copyright (C) 2021 Daiwa Institute of Research Ltd. All Rights Reserved.
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,11 +19,7 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-/*
-** $Date:: 2016-12-13 17:11:26 +0900 #$
-** $Revision: 7101 $
-** $Author: sypark@FITECHLABS.CO.JP $
-**/
+
 
 #ifndef JOBARG_JADBBACKUP_H
 #define JOBARG_JADBBACKUP_H
@@ -31,7 +28,10 @@
 
 extern int CONFIG_BACKUP_TIME;
 extern int CONFIG_BACKUP_RUN_TIME;
+extern char *CONFIG_TMPDIR;
+extern int CONFIG_JOB_HISTORY;
 
 ZBX_THREAD_ENTRY(jadbbackup_thread, args);
+int ja_datafile_remove_oldjob(int day);
 
 #endif
