@@ -2,6 +2,7 @@
 ** Job Arranger for ZABBIX
 ** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
 ** Copyright (C) 2013 Daiwa Institute of Research Business Innovation Ltd. All Rights Reserved.
+** Copyright (C) 2021 Daiwa Institute of Research Ltd. All Rights Reserved.
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,11 +19,6 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-/*
-** $Date:: 2020-06-08 08:56:47 +0900 #$
-** $Revision: 7516 $
-** $Author: sypark@FITECHLABS.CO.JP $
-**/
 
 #include <json.h>
 #include "common.h"
@@ -31,7 +27,6 @@
 #include "log.h"
 
 #include "jacommon.h"
-#include "jajobdb.h"
 #include "jatelegram.h"
 #include "jastr.h"
 #include "jatar.h"
@@ -65,8 +60,6 @@ int ja_fcopy_begin(ja_job_object * job, zbx_sock_t * sock)
     case JA_AGENT_METHOD_TEST:
         if (strcmp(job->type, JA_PROTO_VALUE_PUTFILE) == 0) {
             job->status = JA_AGENT_STATUS_CLOSE;
-            if (ja_jobdb_insert(job) == FAIL)
-                goto error;
             if (ja_fcopy_thread(job, sock) == FAIL)
                 goto error;
         } else if (strcmp(job->type, JA_PROTO_VALUE_GETFILE) == 0) {
@@ -201,10 +194,8 @@ unsigned __stdcall ja_fcopy_getfile_thread(ja_fcopy_args_t * args)
     ret = SUCCEED;
   error:
     if (args != NULL) {
-        if (args->job != NULL)
-            zbx_free(args->job);
-        if (args->s != NULL)
-            zbx_free(args->s);
+        zbx_free(args->job);
+        zbx_free(args->s);
         zbx_free(args);
     }
     if (ret == SUCCEED) {
@@ -360,10 +351,8 @@ unsigned __stdcall ja_fcopy_putfile_thread(ja_fcopy_args_t * args)
     ret = SUCCEED;
   error:
     if (args != NULL) {
-        if (args->job != NULL)
-            zbx_free(args->job);
-        if (args->s != NULL)
-            zbx_free(args->s);
+        zbx_free(args->job);
+        zbx_free(args->s);
         zbx_free(args);
     }
     if (ret == SUCCEED) {
@@ -587,7 +576,6 @@ int ja_fcopy_putfile_chksum(char *chksum, char *dir, ja_job_object * job)
   error:
     if (jp_chksum != NULL)
         json_object_put(jp_chksum);
-    if (fullname != NULL)
-        zbx_free(fullname);
+    zbx_free(fullname);
     return ret;
 }
