@@ -2,6 +2,7 @@
 ** Job Arranger for ZABBIX
 ** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
 ** Copyright (C) 2013 Daiwa Institute of Research Business Innovation Ltd. All Rights Reserved.
+** Copyright (C) 2021 Daiwa Institute of Research Ltd. All Rights Reserved.
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,11 +19,6 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-/*
-** $Date:: 2020-06-08 13:18:57 +0900 #$
-** $Revision: 7518 $
-** $Author: matsubara@FITECHLABS.CO.JP $
-**/
 
 #include "common.h"
 #include "comms.h"
@@ -39,12 +35,13 @@
 
 #include "jacommon.h"
 #include "jahostname.h"
-#include "jajobdb.h"
 #include "listener.h"
 #include "executive.h"
 #include "jobarg_agentd.h"
 #include "jadbbackup.h"
 
+#include <dirent.h>
+
 /******************************************************************************
  *                                                                            *
  *                                                                            *
@@ -289,7 +286,6 @@ static void jobarg_load_config(int requirement)
         {"JaServerPort",      &CONFIG_SERVER_PORT,         TYPE_INT,    PARM_OPT,  1,   65535},
         {"JaListenPort",      &CONFIG_LISTEN_PORT,         TYPE_INT,    PARM_OPT,  1,   65535},
         {"JaSendRetry",       &CONFIG_SEND_RETRY,          TYPE_INT,    PARM_OPT,  0,   3600},
-        {"JaDatabaseFile",    &CONFIG_DATABASE_FILE,       TYPE_STRING, PARM_MAND, 0,   0},
         {"JaJobHistory",      &CONFIG_JOB_HISTORY,         TYPE_INT,    PARM_OPT,  1,   365},
         {"JaBackupTime",      &CONFIG_BACKUP_TIME,         TYPE_INT,    PARM_OPT,  1,   24},
         {"JaBackupRunTime",      &CONFIG_BACKUP_RUN_TIME,  TYPE_INT,    PARM_OPT,  0,   24},
@@ -315,11 +311,6 @@ static void jobarg_load_config(int requirement)
         zbx_error("Server must be defined");
         exit(EXIT_FAILURE);
     }
-    if (ZBX_CFG_FILE_REQUIRED == requirement
-        && NULL == CONFIG_DATABASE_FILE) {
-        zbx_error("Database file must be defined");
-        exit(EXIT_FAILURE);
-    }
     if (ZBX_CFG_FILE_REQUIRED == requirement && NULL == CONFIG_EXTJOB_PATH) {
         zbx_error("extjob path must be defined");
         exit(EXIT_FAILURE);
@@ -399,29 +390,80 @@ int MAIN_ZABBIX_ENTRY()
     int thread_num = 0;
     int cnt = 0;
 
+    DIR* dir;
+    FILE* fp;
+    int tmp_cnt = 0;
+    int folder_create_status;
+    char folderpath[JA_FILE_PATH_LEN];
+    char tmp_file[JA_FILE_PATH_LEN];
+    char* tmp_folder[] = { "begin","close","data","end","error","exec",NULL };
+
 #ifdef _WINDOWS
     DWORD res;
 #else
     int status;
 #endif
-    if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
+	
+	if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
         zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
     } else {
         zabbix_open_log(LOG_TYPE_FILE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
     }
-
+	
     zabbix_log(LOG_LEVEL_INFORMATION,
                "Starting Job Arranger Agent. Job Arranger %s (revision %s).",
                JOBARG_VERSION, JOBARG_REVISION);
 
-    if (FAIL == ja_jobdb_init()) {
-        zabbix_log(LOG_LEVEL_CRIT, "Init database failed: %s",
-                   CONFIG_DATABASE_FILE);
-        exit(EXIT_FAILURE);
-    }
 
     zabbix_log(LOG_LEVEL_DEBUG, "My host name is [%s]", CONFIG_HOSTNAME);
 
+    //
+     //check for tmp folders before agent start.
+    tmp_cnt = 0;
+    while (tmp_folder[tmp_cnt] != NULL) {
+
+        zbx_snprintf(folderpath, sizeof(folderpath), "%s%c%s", CONFIG_TMPDIR, JA_DLM, tmp_folder[tmp_cnt]);
+        zabbix_log(LOG_LEVEL_INFORMATION, "Use folder [%s]", folderpath);
+#if defined _WINDOWS
+        folder_create_status = _mkdir(folderpath);
+#else
+        folder_create_status = mkdir(folderpath,JA_PERMISSION);
+        chmod(folderpath, JA_PERMISSION);
+#endif
+        if (folder_create_status != 0) {
+            if (errno == EEXIST) {
+                zabbix_log(LOG_LEVEL_DEBUG, "Directory already exist in %s", folderpath);
+            }
+            else {
+                zabbix_log(LOG_LEVEL_ERR, "Directory cannot be created[%s].\nExiting jobarg_agentd (%s)", folderpath, strerror(errno));
+                exit(FAIL);
+            }
+        }
+        //check for read/write permission
+        //check for read access.
+        dir = opendir(folderpath);
+        if (dir == NULL) {
+            zabbix_log(LOG_LEVEL_ERR, "Directory cannot be opened.[%s].\n Exiting jobarg_agentd (%s)", folderpath, strerror(errno));
+            exit(FAIL);
+        }
+        closedir(dir);
+        //check for write access
+        zbx_snprintf(tmp_file, sizeof(tmp_file), "%s%ctmp.txt", folderpath, JA_DLM);
+
+        fp = fopen(tmp_file, "wb");
+        if (fp == NULL) {
+            zabbix_log(LOG_LEVEL_ERR, "Cannot create file under directory[%s].\nExiting jobarg_agentd (%s)", folderpath, strerror(errno));
+            exit(FAIL);
+        }
+        fclose(fp);
+        if (remove(tmp_file) != 0) {
+            zabbix_log(LOG_LEVEL_ERR, "Cannot delete file under directory[%s].\nExiting jobarg_agentd (%s)", folderpath, strerror(errno));
+            exit(FAIL);
+        }
+        tmp_cnt++;
+    }
+    //
+
     cnt = 0;
     while (1) {
         if (SUCCEED == zbx_tcp_listen(&listen_sock, CONFIG_LISTEN_IP, (unsigned short) CONFIG_LISTEN_PORT)) {
@@ -450,6 +492,7 @@ int MAIN_ZABBIX_ENTRY()
         (ZBX_THREAD_HANDLE *) zbx_calloc(threads, threads_num,
                                          sizeof(ZBX_THREAD_HANDLE));
 
+  
     /* start the executive thread */
     thread_args =
         (zbx_thread_args_t *) zbx_malloc(NULL, sizeof(zbx_thread_args_t));
@@ -457,6 +500,7 @@ int MAIN_ZABBIX_ENTRY()
     thread_args->args = NULL;
     threads[thread_num++] =
         zbx_thread_start(executive_thread, thread_args);
+    
 
     /* start the listener thread */
     thread_args =
@@ -499,7 +543,6 @@ int MAIN_ZABBIX_ENTRY()
     }
     THIS_SHOULD_NEVER_HAPPEN;
 #endif
-    ja_db_close();
     zbx_on_exit();
 
     return SUCCEED;
@@ -615,6 +658,6 @@ int main(int argc, char **argv)
         break;
     }
 
-    START_MAIN_ZABBIX_ENTRY(CONFIG_ALLOW_ROOT);
+	START_MAIN_ZABBIX_ENTRY(CONFIG_ALLOW_ROOT);
     exit(SUCCEED);
 }
