@@ -2,6 +2,7 @@
 ** Job Arranger for ZABBIX
 ** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
 ** Copyright (C) 2013 Daiwa Institute of Research Business Innovation Ltd. All Rights Reserved.
+** Copyright (C) 2021 Daiwa Institute of Research Ltd. All Rights Reserved.
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,11 +19,6 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-/*
-** $Date:: 2020-06-08 13:18:57 +0900 #$
-** $Revision: 7518 $
-** $Author: matsubara@FITECHLABS.CO.JP $
-**/
 
 #include "common.h"
 #include "comms.h"
@@ -46,6 +42,7 @@ const char usage_message[] = "[-hV] [-c <file>]";
 const char *help_message[] = {
     "Options:",
     "  -c --config <file>              Absolute path to the configuration file",
+	"  -f --foreground     Run Job Arranger monitor in foreground",
     "",
     "Other options:",
     "  -h --help                       Give this help",
@@ -58,13 +55,14 @@ const char *help_message[] = {
 /* long options */
 static struct zbx_option longopts[] = {
     {"config", 1, NULL, 'c'},
+	{"foreground",		0,	NULL,	'f'},
     {"help", 0, NULL, 'h'},
     {"version", 0, NULL, 'V'},
     {NULL}
 };
 
 /* short options */
-static char shortopts[] = "c:hV";
+static char shortopts[] = "c:hV:f";
 
 /* end of COMMAND LINE OPTIONS */
 
@@ -113,6 +111,8 @@ int  CONFIG_LOG_SLOW_QUERIES       = 0;
 int  CONFIG_PROXYCONFIG_FREQUENCY  = 0;
 int  CONFIG_PROXYDATA_FREQUENCY    = 0;
 
+char *CONFIG_LOG_TYPE_STR ;
+
 /******************************************************************************
  *                                                                            *
  * Function:                                                                  *
@@ -184,6 +184,9 @@ static void parse_commandline(int argc, char **argv)
             version_jobarg();
             exit(FAIL);
             break;
+        case 'f':
+            JAZ_TASK_FLAG_FOREGROUND = 1;
+            break;
         default:
             usage();
             exit(FAIL);
@@ -229,6 +232,7 @@ static void ja_load_config(const char *config_file)
         {"JaMonitorInterval", &CONFIG_JAMONITOR_INTERVAL, TYPE_INT,    PARM_OPT,  1,    60},
         {"JaSenderScript",    &CONFIG_SENDER_SCRIPT,      TYPE_STRING, PARM_OPT,  0,    0},
         {"JaExecutionUser",   &CONFIG_JA_EXECUTION_USER,  TYPE_STRING, PARM_OPT,  0,    0},
+		{"LogType",			  &CONFIG_LOG_TYPE_STR,       TYPE_STRING, PARM_OPT,	0,	0},
         {NULL}
     };
 
@@ -518,13 +522,26 @@ int MAIN_ZABBIX_ENTRY()
 {
     zbx_thread_args_t *thread_args;
     int               thread_num = 0;
-    int               status;
+    int               status, console_flag=0;
 
-    if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
-        zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
+    if (JAZ_TASK_FLAG_FOREGROUND)
+    {
+    	printf("Starting Job Arranger Server. Job Arranger %s (revision %s).\nPress Ctrl+C to exit.\n\n",
+    			 JOBARG_VERSION, JOBARG_REVISION);
+    	if (0 == strcmp(CONFIG_LOG_TYPE_STR, ZBX_OPTION_LOGTYPE_CONSOLE))
+    	{
+    		zabbix_open_log(LOG_TYPE_CONSOLE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
+    		console_flag = 1;
+    	}
     }
-    else {
-        zabbix_open_log(LOG_TYPE_FILE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
+    if (0 == console_flag)
+    {
+    	if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
+    		zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
+    	}
+    	else {
+    		zabbix_open_log(LOG_TYPE_FILE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
+    	}
     }
 
     zabbix_log(LOG_LEVEL_INFORMATION, "Starting Job Arranger monitor. Job Arranger %s (revision %s).",
