@@ -2,6 +2,7 @@
 ** Job Arranger for ZABBIX
 ** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
 ** Copyright (C) 2013 Daiwa Institute of Research Business Innovation Ltd. All Rights Reserved.
+** Copyright (C) 2021 Daiwa Institute of Research Ltd. All Rights Reserved.
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,11 +19,6 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-/*
-** $Date:: 2020-06-08 13:18:57 +0900 #$
-** $Revision: 7518 $
-** $Author: matsubara@FITECHLABS.CO.JP $
-**/
 
 #include "common.h"
 #include "comms.h"
@@ -46,6 +42,7 @@
 #include "jamsgsnd/jamsgsnd.h"
 #include "jaselfmon/jaselfmon.h"
 
+
 #define INIT_SERVER(type, count)								\
 	process_type = type;									\
 	process_num = server_num - server_count + count;					\
@@ -122,6 +119,7 @@ int	CONFIG_JAMSGSND_INTERVAL	= 1;
 int	CONFIG_JAMSGSND_FORKS		= 1;
 int	CONFIG_EXTJOB_WAITTIME		= 300;
 char	*CONFIG_JA_PS_COMMAND		= "ps -ef | awk '{ print $2,$3 }'";
+char *CONFIG_JA_ZABBIX_URL = NULL;
 
 /* for Zabbix */
 int	CONFIG_ALERTER_FORKS		= 1;
@@ -313,6 +311,7 @@ static void zbx_load_config()
 		{"JaExecutionUser",	&CONFIG_JA_EXECUTION_USER,	TYPE_STRING,		PARM_OPT,	0,	0},
 		{"JaMsgsndInterval",	&CONFIG_JAMSGSND_INTERVAL,	TYPE_INT,		PARM_OPT,	1,	9999999},
 		{"JaExtjobWaitTime",	&CONFIG_EXTJOB_WAITTIME,	TYPE_INT,		PARM_OPT,	0,	9999999},
+		{"JaZabbixURL",	&CONFIG_JA_ZABBIX_URL,	TYPE_STRING,		PARM_OPT,	0,	0},
 		{NULL}
 	};
 
@@ -435,7 +434,7 @@ int main(int argc, char **argv)
  ******************************************************************************/
 int MAIN_ZABBIX_ENTRY()
 {
-	pid_t		pid;
+	pid_t pid;
 	zbx_sock_t	listen_sock;
 	int		i, server_num = 0, server_count = 0, console_flag = 0;
 
@@ -462,9 +461,12 @@ int MAIN_ZABBIX_ENTRY()
 	ja_log("JASERVER000001", 0, NULL, 0, JOBARG_VERSION, JOBARG_REVISION);
 
 	ja_init_selfmon_collector();
+
+
 	threads_num = CONFIG_JARUN_FORKS + CONFIG_JATRAPPER_FORKS + CONFIG_JAJOB_FORKS
 			+ CONFIG_JAJOBNET_FORKS + CONFIG_JALOADER_FORKS + CONFIG_JABOOT_FORKS
 			+ CONFIG_JAMSGSND_FORKS + CONFIG_JASELFMON_FORKS;
+
 	threads = zbx_calloc(threads, threads_num, sizeof(pid_t));
 
 	if (FAIL == zbx_tcp_listen(&listen_sock, CONFIG_LISTEN_IP, (unsigned short) CONFIG_LISTEN_PORT)) {
@@ -481,7 +483,7 @@ int MAIN_ZABBIX_ENTRY()
 	}
 
 	if (0 == server_num) {
-		ja_log("JASERVER000003", 0, NULL, 0);
+			ja_log("JASERVER000003", 0, NULL, 0);
 
 		while (-1 == wait(&i)) {
 			if (EINTR != errno) {
@@ -489,7 +491,6 @@ int MAIN_ZABBIX_ENTRY()
 				break;
 			}
 		}
-
 		THIS_SHOULD_NEVER_HAPPEN;
 		zbx_on_exit();
 	} else if (server_num <= (server_count += CONFIG_JAJOBNET_FORKS)) {
@@ -515,9 +516,8 @@ int MAIN_ZABBIX_ENTRY()
 		main_jamsgsnd_loop();
 	} else if (server_num <= (server_count += CONFIG_JASELFMON_FORKS)) {
 		INIT_SERVER(JA_PROCESS_TYPE_SELFMON, CONFIG_JASELFMON_FORKS);
-		main_jaselfmon_loop();
-	}
-
+		main_jaselfmon_loop(threads , threads_num);
+}
 	return SUCCEED;
 }
 
